.. _aiomsa-exceptions:

==========
Exceptions
==========

.. currentmodule:: aiomsa.exceptions

.. automodule:: aiomsa.exceptions
   :members:

Hierarchy
=========

* :exc:`AioMsaError`

  * :exc:`DuplicateRouteError`

  * :exc:`ClientError`

    * :exc:`ClientRestartError`
    * :exc:`ClientStoppedError`
    * :exc:`ClientRuntimeError`
